Get questions with the section to which each belongs.
Source:R/extract.R
get_questions_by_section.RdExtract metadata about questions and variables and their parent section from the questionnaire JSON as a data frame.
Value
Data frame with the following columns
titleandsection_id(PublicKey) for sectionsAll the columns from
get_questions()andget_variables()