When exported, multi-select questions become a set of variables whose
name is a combination of the variable name and answer option value in
Designer. This function extracts answer options in convenient form to
either label variables in data or columns in display tables,
where expected specification for labelling is of the form
{variable} = {variable label}.
Arguments
- json_path
Character. Full path to the Survey Solutions questionnaire JSON file (e.g.,
~/my_proj/path/to/document.json).- categories_dir
Character. Path to the
Categoriesdirectory of metadata and/or where the.xlsxfiles containing reusable categories can be found.- varname
Variable name. Bare name of variable whose answer options to extract.
- to_exclude
Numeric vector. Code of answer options to exclude.